Introduction
============

Pipeline is an asset packaging library for Django, providing
both CSS and JavaScript concatenation and compression, built-in JavaScript
template support, and optional data-URI image and font embedding.

You can report bugs and discuss features on the `issues page <https://github.com/jazzband/django-pipeline/issues>`_.

You can discuss features or ask questions on the IRC channel on freenode : `#django-pipeline <irc://irc.freenode.net/django-pipeline>`_


Table Of Contents
=================

.. toctree::
   :maxdepth: 2

   installation
   configuration
   usage
   compressors
   compilers
   templates
   storages
   signals
   using


Indices and tables
==================

* :ref:`search`
